@@ -1,7 +1,7 @@
 context("bandwidths")
 
-t = function(x) {}
-good = function(x, kernel, start, support) {}
+t <- function(x) {}
+good <- function(x, kernel, start, support) {}
 
 expect_error(add_bw("t", t))
 expect_silent(add_bw("t", good))
@@ -19,5 +19,7 @@ expect_equal(get_standard_bw(kernel_str = "gamma", start_str = "uniform"), "ucv"
 expect_equal(get_standard_bw(kernel_str = "epanechnikov", start_str = "constant"), "nrd0")
 expect_equal(get_standard_bw(kernel_str = "triangular", start_str = "uniform"), "nrd0")
 
-expect_error(kdensity(mtcars$mpg, kernel = "uniform", start = "gamma"),
-             "Normalization error: The function will not integrate.Two common causes are: 1.) The kernel is non-smooth, try a smooth kernel if possible. 2.) The supplied support is incorrect.")
+expect_error(
+  kdensity(mtcars$mpg, kernel = "uniform", start = "gamma"),
+  "Normalization error: The function will not integrate.Two common causes are: 1.) The kernel is non-smooth, try a smooth kernel if possible. 2.) The supplied support is incorrect."
+)
